Package: geoknife
Type: Package
Title: Web-Processing of Large Gridded Datasets
Version: 1.6.11
Authors@R: c( person("Jordan", "Read", role = c("aut"),
    email = "jread@usgs.gov"),
    person("Jordan", "Walker", role = c("aut"),
    email = "jiwalker@usgs.gov"),
    person("Alison", "Appling", role = c("aut"),
    email = "aappling@usgs.gov"),
    person("David", "Blodgett", role = c("aut", "cre"),
    email = "dblodgett@usgs.gov"),
    person("Emily", "Read", role = c("aut"),
    email = "eread@usgs.gov"),
    person("Luke", "Winslow", role = c("aut"),
    email = "lwinslow@usgs.gov"),
    person("Lindsay", "Carr", role = c("aut"),
    email = "lcarr@usgs.gov"),
    person("David", "Watkins", role = c("aut"),
    email = "wwatkins@usgs.gov"))
Description: Processes gridded datasets found on the U.S. Geological Survey
    Geo Data Portal web application or elsewhere, using a web-enabled workflow
    that eliminates the need to download and store large datasets that are reliably
    hosted on the Internet. The package provides access to several data subset and
    summarization algorithms that are available on remote web processing servers (Read et al. (2015) <doi:10.1111/ecog.01880>).
License: CC0
URL: https://github.com/DOI-USGS/geoknife
BugReports: https://github.com/DOI-USGS/geoknife/issues
Copyright: This software is in the public domain because it contains
        materials that originally came from the United States
        Geological Survey, an agency of the United States Department of
        Interior.
Depends: R (>= 3.5)
Imports: whisker, xml2, methods, httr (>= 1.0.0), curl, utils, progress
        (>= 1.1.2), sf
Suggests: testthat, xtable, knitr, rmarkdown, ggmap, dplyr, rasterVis,
        ggplot2, sp, raster
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-07-03 19:46:46 UTC; dblodgett
Author: Jordan Read [aut],
  Jordan Walker [aut],
  Alison Appling [aut],
  David Blodgett [aut, cre],
  Emily Read [aut],
  Luke Winslow [aut],
  Lindsay Carr [aut],
  David Watkins [aut]
Maintainer: David Blodgett <dblodgett@usgs.gov>
Repository: CRAN
Date/Publication: 2023-07-06 08:00:12 UTC
