% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/04-webprocess-obj.R
\name{webprocess}
\alias{webprocess}
\alias{webprocess,missing-method}
\alias{webprocess,character-method}
\alias{webprocess,ANY-method}
\title{create webprocess object}
\usage{
webprocess(.Object, ...)

\S4method{webprocess}{missing}(.Object, ...)

\S4method{webprocess}{character}(
  .Object = c("summary", "unweighted summary", "coverage summary", "subset",
    "coverage subset"),
  ...
)

\S4method{webprocess}{ANY}(.Object, ...)
}
\arguments{
\item{.Object}{any object that can be coerced into \linkS4class{webprocess}}

\item{...}{additional arguments passed initialize method (e.g., \code{url}, \code{version})}
}
\value{
the webprocess object
}
\description{
create webprocess object
}
\author{
Jordan S Read
}
