% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/query-webdata-times.R
\name{times_query}
\alias{times_query}
\alias{times_query,webdata-method}
\alias{times_query,webdata,missing-method}
\alias{times_query,webdata,webprocess-method}
\title{times query}
\usage{
times_query(fabric, knife)

\S4method{times_query}{webdata,missing}(fabric, knife)

\S4method{times_query}{webdata,webprocess}(fabric, knife)
}
\description{
query a webdata object for the time range
}
\keyword{internal}
