% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/variables-webdata.R
\docType{methods}
\name{variables}
\alias{variables}
\alias{variables<-}
\alias{variables,webdata-method}
\alias{variables<-,webdata-method}
\title{the variables of a webdata object}
\usage{
variables(.Object)
variables(.Object) <- value

variables(.Object) <- value

\S4method{variables}{webdata}(.Object)

\S4method{variables}{webdata}(.Object) <- value
}
\arguments{
\item{.Object}{a \code{\link{webdata}} object}

\item{value}{a character vector for variables}
}
\description{
access or set the variables of a webdata object
}
